import 'package:flutter/material.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';

class ApplyPermissionDialog extends Dialog {
  String? title;
  Function? onAgreed;
  String? permissionType;
  String? defaultIcon;

  ApplyPermissionDialog(
      {super.key,
      required permissionType,
      required onAgreed,
      this.defaultIcon}) {
    this.permissionType = permissionType;
    this.onAgreed = onAgreed;
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Container(
          width: 290,
          height: 275,
          padding: const EdgeInsets.only(left: 30, right: 30, top: 30),
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.circular(10),
          ),
          child: Column(
            children: [
              const Center(
                child: Text(
                  "温馨提示",
                  style: TextStyle(
                      fontSize: 20,
                      color: Colors.black,
                      fontWeight: FontWeight.bold),
                ),
              ),
              Container(
                margin: const EdgeInsets.only(top: 15),
                child: Row(
                  children: [
                    SizedBox(
                      width: 30,
                      height: 130,
                      child: Column(
                        children: [
                          Image.asset(getPermissionTypeIconPath(defaultIcon!),
                              width: 30, height: 30),
                        ],
                      ),
                    ),
                    SizedBox(
                      width: 200,
                      height: 130,
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Container(
                            margin: const EdgeInsets.only(left: 8),
                            child: Text(
                              getPermissionTitle(permissionType!),
                              style: const TextStyle(
                                  color: Colors.black, fontSize: 18),
                            ),
                          ),
                          Container(
                            margin: const EdgeInsets.only(top: 10, left: 8),
                            child: Text(
                              getPermissionDesc(permissionType!),
                              style: const TextStyle(
                                  color: Color(0xFF999999), fontSize: 15),
                            ),
                          )
                        ],
                      ),
                    )
                  ],
                ),
              ),
              SizedBox(
                height: 68,
                child: Column(
                  children: [
                    Row(
                      children: [
                        GestureDetector(
                          onTap: () {
                            EasyLoading.showToast(
                                getToastText(permissionType!));
                            Navigator.pop(context);
                          },
                          child: Container(
                            width: 98,
                            height: 40,
                            decoration: BoxDecoration(
                              color: const Color(0xFF999999),
                              borderRadius: BorderRadius.circular(20),
                            ),
                            child: const Center(
                              child: Text(
                                "禁止",
                                style: TextStyle(
                                    color: Colors.white, fontSize: 14),
                              ),
                            ),
                          ),
                        ),
                        GestureDetector(
                          onTap: () {
                            Navigator.pop(context);
                            onAgreed!();
                          },
                          child: Container(
                            margin: const EdgeInsets.only(left: 34),
                            width: 98,
                            height: 40,
                            decoration: BoxDecoration(
                              gradient: const LinearGradient(
                                  begin: Alignment.centerLeft,
                                  end: Alignment.centerRight,
                                  colors: [
                                    Color(0xFFFE6E55),
                                    Color(0xFFFF299F)
                                  ]),
                              borderRadius: BorderRadius.circular(20),
                            ),
                            child: const Center(
                              child: Text(
                                "去开启",
                                style: TextStyle(
                                    color: Colors.white, fontSize: 14),
                              ),
                            ),
                          ),
                        )
                      ],
                    ),
                    Container(
                      height: 19,
                    )
                  ],
                ),
              )
            ],
          ),
        )
      ],
    );
  }

  static showApplyPermissionDialog(BuildContext context,
      {required String permissionType, required Function onAgreed}) {
    return showDialog(
        barrierDismissible: true,
        context: context,
        builder: (BuildContext context) {
          return WillPopScope(
            onWillPop: _onWillPop,
            child: ApplyPermissionDialog(
              permissionType: permissionType,
              onAgreed: onAgreed,
            ),
          );
        });
  }

  static Future<bool> _onWillPop() async {
    return false;
  }

  String getPermissionTypeIconPath(String type) {
    String iconPath = "assets/images/common/permission_default_icon";
    if (type != "") {
      iconPath = type;
    }
    return iconPath;
  }

  String getPermissionTitle(String type) {
    String permissionTitle = "保障体验流畅";
    if (type != "") {
      permissionTitle = type;
    }
    return permissionTitle;
  }

  String getPermissionDesc(String type) {
    String permissionDesc = "保障体验流畅";
    if (type != "") {
      permissionDesc = type;
    }
    return permissionDesc;
  }

  String getToastText(String type) {
    String toastText = "你需要授权权限方可使用此功能";
    if (type != "") {
      toastText = type;
    }
    return toastText;
  }
}
